@@ -4,6 +4,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                      level=0.95, level.comb=level,
                      comb.fixed=TRUE, comb.random=TRUE,
                      title="", complab="", outclab="",
+                     label.e="Experimental", label.c="Control",
                      byvar, bylab, print.byvar=TRUE
                      ){
   
@@ -159,6 +160,8 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
               title=title,
               complab=complab,
               outclab=outclab,
+              label.e=label.e,
+              label.c=label.c,
               call=match.call())
   ##
   if (!missing(byvar)) res$byvar <- byvar
