@@ -1,7 +1,10 @@
 metaprop <- function(event, n, studlab,
                      data=NULL, subset=NULL,
                      freeman.tukey=TRUE,
-                     level=0.95, level.comb=level
+                     level=0.95, level.comb=level,
+                     comb.fixed=TRUE, comb.random=TRUE,
+                     title="", complab="", outclab="",
+                     byvar, bylab, print.byvar=TRUE
                      ){
   
   
@@ -108,8 +111,15 @@ metaprop <- function(event, n, studlab,
               sm="proportion", method=m$method,
               freeman.tukey=freeman.tukey,
               level=level, level.comb=level.comb,
+              comb.fixed=comb.fixed,
+              comb.random=comb.random,
+              title="", complab="", outclab="",
               call=match.call())
-
+  ##
+  if (!missing(byvar)) res$byvar <- byvar
+  if (!missing(bylab)) res$bylab <- bylab
+  res$print.byvar <- print.byvar
+  
   class(res) <- c("metaprop", "meta")
 
   res
